#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::apply
#
# @summary defined type `ora_cis::apply`
# With this defined type, you can select a subset of the CIS controls to apply to your database. Currently the sets `BASIC`, `AUDIT_ONLY` and `ALL` are predefined.
# 
# You can also define your own sets. See [here](/docs/ora_cis/define_sets.html) on how to define your own levels.
# 
# Here is an example on how to use this:
# 
# ```
# ora_cis::apply {'DB1:
#   db_version  => 'db19c',
#   doc_version => 'V1.0.0',
#   control_set => 'BASIC'
# }
# ```
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Optional[String[1]]] db_version
#    The database version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) database version to your database.
#    If you also don't specify a `db_version`, Puppet will detect the version of Oracle running and use this to determine the `db_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your database.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `db_version`.
#
# @param [String[1]] set
#    With this parameter, you can specify the set of CIS controls you want to apply to your database.
#    Currently, we have the following sets predefined:
#    - ALL
#    - BASIC
#    - AUDIT_ONLY
#    Check [here](/docs/ora_cis/predefined_sets.md) for a description of the predefined sets.
#
#--++--
define ora_cis::apply(
  String[1]           $set         = 'BASIC',
  Optional[String[1]] $db_version  = ora_cis::default_db_version($title),
  Optional[String[1]] $doc_version = ora_cis::default_doc_version($db_version),
)
{
  $control_set = lookup("ora_cis::sets::${set}", Array[String[1]], undef, undef)

  if $db_version and $doc_version{
    ora_cis::validate_versions($db_version, $doc_version)
    $control_map     = lookup('ora_cis::control_map', Hash[String[1], String[1]], undef, undef)
    $nonpdb_controls = lookup('ora_cis::nonpdb_controls', Hash[String[1], String[1]], undef, undef)

    $sid = $title
    $sanitized_doc_version = regsubst($doc_version,/\./,'_','G').downcase

    echo {"Apply CIS control set ${set} from ${db_version} ${doc_version} on ${sid}.": withpath => false,}

    $selected_controls = $control_map.filter |$chapter, $control| {
      $control in $control_set
    }

    if ora_config::is_pluggable_db($sid) {
        $current_controls = $selected_controls - $nonpdb_controls.keys
        $nonpdb_controls.each | $paragraph, $control| {
          if $control in $selected_controls.values {
            alert("${control} in CIS skipped on ${title} because not applicable on pluggable database")
          }
        }
    } else {
      $current_controls = $selected_controls
    }


    $current_controls.each |String[1] $paragraph_name, String[1] $control_name | {
      $cis_name           = "${db_version}::${sanitized_doc_version}::${set.downcase}::${control_name}::${sid.downcase}"
      # Generate puppet puppet_code
      $puppet_code = @("PUPPET")
      class $cis_name 
        {
          ora_cis::controls::$control_name { "${sid}": }
        }
      PUPPET
      easy_type::evaluate_puppet($puppet_code)
      include $cis_name
    }
  } else {
    warning('skipping because db_version and/or doc_version is not set or found. Might be running on next run.')
  }
}
