#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::all_is_revoked_from_unauthorized_grantee_on_aud
#
# @summary The Oracle database `SYS.
# AUD$` table contains all the audit records for the
# database of the non-Data Manipulation Language (DML) events, such as `ALTER`,
# `DROP`, and `CREATE`, and so forth. (DML changes need trigger-based audit events
# to record data alterations.) Unauthorized grantees should not have full access
# to that table.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::all_is_revoked_from_unauthorized_grantee_on_aud: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::all_is_revoked_from_unauthorized_grantee_on_aud::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_is_revoked_from_unauthorized_grantee_on_aud` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.1.3.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 5.1.3.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 5.1.3.1
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#--++--
#
define ora_cis::controls::all_is_revoked_from_unauthorized_grantee_on_aud(
  Array $exclude = ora_cis::lookup_setting('exclude', []),
){
  $sid = $title
  ora_cis_setup { "all_is_revoked_from_unauthorized_grantee_on_aud on ${sid}":
    ensure => 'present',
  }
  $control_excludes = []

  $all_exclude_controls = $control_excludes + $exclude
  $users_to_revoke = ora_config::on_sid($::ora_access_to_aud, $sid) - $all_exclude_controls

  $users_to_revoke.each |$user| {
    ora_object_grant{"${user}->SYS.AUD$@${sid}":
      permissions => [],
    }
  }
}
