#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::any_is_revoked_from_unauthorized_grantee
#
# @summary The Oracle database `ANY` keyword provides the user the capability to alter any
# item in the catalog of the database. Unauthorized grantees should not have that
# keyword assigned to them.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::any_is_revoked_from_unauthorized_grantee: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::any_is_revoked_from_unauthorized_grantee::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `any_is_revoked_from_unauthorized_grantee` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.2.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 5.2.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 5.2.1
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::any_is_revoked_from_unauthorized_grantee(
  Array $exclude_users = ora_cis::lookup_setting('exclude_users', []),
  Array $exclude_roles = ora_cis::lookup_setting('exclude_roles', []),
  Array $exclude_privs = ora_cis::lookup_setting('exclude_privs', []),
){
  $sid = $title
  $all_exclude_users = ora_config::on_sid($::ora_maintained_users, $sid) + $exclude_users
  $all_exclude_roles = ora_config::on_sid($::ora_maintained_roles, $sid) + $exclude_roles

  ora_cis_setup { "any_is_revoked_from_unauthorized_grantee on ${sid}":
    ensure => 'present',
  }

  $privs_to_check = ora_config::on_sid($::ora_any_privileges, $sid) - $exclude_privs
  $privs_to_check.each |$priv| {
    ora_cis::internal::revoke_user_rights{"${priv}@${sid}":
      exclude => $all_exclude_users,
    }
    ora_cis::internal::revoke_role_rights{"${priv}@${sid}":
      exclude => $all_exclude_roles,
    }
  }
}
