#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::audsys_aud_unified_access_audit_is_enabled
#
# @summary The `AUDSYS.
# AUD$UNIFIED` holds audit trail records generated by the database.
# Enabling this audit action causes logging of all access attempts to the
# `AUDSYS.AUD$UNIFIED`, whether successful or unsuccessful, regardless of the
# privileges held by the users to issue such statements.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::audsys_aud_unified_access_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::audsys_aud_unified_access_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audsys_aud_unified_access_audit_is_enabled` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 6.2.19
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 6.2.19
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 6.2.19
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::audsys_aud_unified_access_audit_is_enabled()
{
  $sid = $title
  ora_cis_setup { "audsys_aud_unified_access_audit_is_enabled on ${sid}":
    ensure => 'present',
  }

  $cis_audit_policy_exists = ora_config::on_sid($::ora_cis_audit_policy_exists, $sid)

  if $cis_audit_policy_exists[0] == '0' {
    ora_exec { "create CIS_UNIFIED_AUDIT_POLICY on AUDSYS.AUD\$UNIFIED@${sid}":
      statement => @(SQL),
        CREATE AUDIT POLICY CIS_UNIFIED_AUDIT_POLICY 
          ACTIONS ALL
          on AUDSYS.AUD$UNIFIED
        SQL
      }
  } else {
    ora_exec { "modify CIS_UNIFIED_AUDIT_POLICY on AUDSYS.AUD\$UNIFIED@${sid}":
      statement => @(SQL),
        ALTER AUDIT POLICY CIS_UNIFIED_AUDIT_POLICY
          ADD ACTIONS ALL 
          on AUDSYS.AUD$UNIFIED
        SQL
      unless    => @(SQL),
        select OBJECT_NAME from AUDIT_UNIFIED_POLICIES AUD
          WHERE AUD.AUDIT_OPTION_TYPE = 'OBJECT ACTION' 
          AND AUD.OBJECT_SCHEMA = 'AUDSYS' 
          AND AUD.OBJECT_NAME = 'AUD$UNIFIED'
          AND POLICY_NAME = 'CIS_UNIFIED_AUDIT_POLICY'
      SQL
    }
  }
}
