#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user
#
# @summary The `authentication_type='EXTERNAL'` setting determines whether or not a user
# can be authenticated by a remote OS to allow access to the database with full
# authorization. This setting should not be used.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_users_authentication_type_is_not_set_to_external_for_any_user` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 4.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 4.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 4.3
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Integer[8, default]] preferred_value
#    The preferred value to use.
#    Some rules allow multiple values. The rule implement a default value, but when you want an other value, you can use this parameter.
#
#--++--
#
define ora_cis::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user(
  Array              $exclude         = ora_cis::lookup_setting('exclude',[]),
  Integer[8,default] $preferred_value = ora_cis::lookup_setting('preferred_value', 12),
){
  $sid = $title

  ora_cis_setup { "dba_userspassword_is_not_set_to_external_for_any_user on ${sid}":
    ensure => 'present'
  }

  $users_to_check = ora_config::on_sid($::ora_users_with_external_password, $sid) - $exclude
  $users_to_check.each |$user| {
    $full_name = "Ora_user[${user}@${sid}]password"
    resource_value { $full_name:
      value        => ora_config::generated_password($preferred_value),
      allow_create => true,
    }
  }
}

