#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::execute_any_procedure_is_revoked_from_outln
#
# @summary Remove unneeded `EXECUTE ANY PROCEDURE` privileges from `OUTLN`.
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::execute_any_procedure_is_revoked_from_outln: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::execute_any_procedure_is_revoked_from_outln::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_any_procedure_is_revoked_from_outln` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.2.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 5.2.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 5.2.3
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#--++--
#
define ora_cis::controls::execute_any_procedure_is_revoked_from_outln(
  Array $exclude = ora_cis::lookup_setting('exclude', []),
){
  $sid = $title
  ora_cis_setup { "execute_any_procedure_is_revoked_from_outln on ${sid}":
    ensure => 'present',
  }
  $users_to_check = ['OUTLN'] - $exclude

  $users_to_check.each |$user| {
    $full_name = "Ora_user[${user}@${sid}]revoked"

    resource_value { $full_name:
      value        => ['EXECUTE ANY PROCEDURE'],
      allow_create => true,
    }
  }
}
