#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::execute_is_revoked_from_public_on_job_scheduler_packages
#
# @summary As described below, Oracle Database PL/SQL "Job Scheduler" packages -
# `DBMS_SCHEDULER` and `DBMS_JOB` – provide APIs to schedule jobs. The user
# `PUBLIC` should not be able to execute these packages.
# - The Oracle database `DBMS_SCHEDULER` package schedules and manages the
#   database and operating system jobs. The user `PUBLIC` should not be able to
#   execute `DBMS_SCHEDULER`.
# - The Oracle database `DBMS_JOB` package schedules and manages the jobs sent to
#   the job queue and has been superseded by the `DBMS_SCHEDULER` package, even
#   though `DBMS_JOB` has been retained for backwards compatibility. The user
#   `PUBLIC` should not be able to execute `DBMS_JOB`. 
#   
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::execute_is_revoked_from_public_on_job_scheduler_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::execute_is_revoked_from_public_on_job_scheduler_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_job_scheduler_packages` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 5.1.1.5
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 5.1.1.5
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 5.1.1.5
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#--++--
#
define ora_cis::controls::execute_is_revoked_from_public_on_job_scheduler_packages(
  Array $list    = ora_cis::lookup_setting('list', undef),
  Array $exclude = ora_cis::lookup_setting('exclude', []),
){
  $sid = $title
  ora_cis_setup { "execute_is_revoked_from_public_on_jobscheduler_packages on ${sid}":
    ensure => 'present',
  }
  $packages = $list - $exclude
  $packages.each | $package | {
    ora_cis::internal::revoke_public_grants {"${package}@${sid}": }
  }
}
