#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::no_public_database_links_exist
#
# @summary Public Database links are used to allow connections between databases.
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::no_public_database_links_exist: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::no_public_database_links_exist::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `no_public_database_links_exist` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 4.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 4.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 4.6
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
#--++--
#
define ora_cis::controls::no_public_database_links_exist()
{
  $sid = $title
  ora_cis_setup { "no_public_database_links_exist on ${sid}":
    ensure => 'present',
  }

  $sql = @(STATEMENT)
  DECLARE
     l_ddl VARCHAR2(1000);
  BEGIN
    FOR rec IN ( SELECT DB_LINK FROM DBA_DB_LINKS WHERE OWNER = 'PUBLIC') LOOP
      l_ddl := 'drop public database link '|| rec.db_link;
      dbms_output.put_line(l_ddl);
      EXECUTE IMMEDIATE (l_ddl);
      END LOOP;
  END;
  /
  | STATEMENT

ora_exec{ "delete_public_database_links@${sid}":
    onlyif    => "SELECT DB_LINK, HOST FROM DBA_DB_LINKS WHERE OWNER = 'PUBLIC'",
    statement => $sql
  }
}
