#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::password_grace_time_is_less_than_or_equal_to_5
#
# @summary The `PASSWORD_GRACE_TIME` setting determines how many days can pass after the
# user's password expires before the user's login capability is automatically
# locked out. The suggested value for this is five days or less.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::password_grace_time_is_less_than_or_equal_to_5: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::password_grace_time_is_less_than_or_equal_to_5::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `password_grace_time_is_less_than_or_equal_to_5` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 3.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 3.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 3.6
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Array] only
#    The list of object to only apply the control to.
#
# @param [Integer[0, 5]] preferred_value
#    The preferred value to use.
#    Some rules allow multiple values. The rule implement a default value, but when you want an other value, you can use this parameter.
#
#--++--
#
define ora_cis::controls::password_grace_time_is_less_than_or_equal_to_5(
  Array        $exclude          = ora_cis::lookup_setting('exclude', []),
  Array        $only             = ora_cis::lookup_setting('only', []),
  Integer[0,5]  $preferred_value = ora_cis::lookup_setting('preferred_value', 5),
){
  $sid = $title
  ora_cis_setup { "password_grace_time_is_less_than_or_equal_to_5 on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::profile_setting{"password_grace_time@${sid}":
    value   =>  $preferred_value,
    exclude => $exclude,
    only    => $only,
  }
}
