#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::controls::password_reuse_max_is_greater_than_or_equal_to_20
#
# @summary The `PASSWORD_REUSE_MAX` setting determines how many different passwords must be
# used before the user is allowed to reuse a prior password. The suggested value
# for this is 20 passwords or greater.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_cis::controls::password_reuse_max_is_greater_than_or_equal_to_20: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_cis::controls::password_reuse_max_is_greater_than_or_equal_to_20::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `password_reuse_max_is_greater_than_or_equal_to_20` to the array value `ora_cis::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_cis/db12c_V3.0.0.html) - paragraph 3.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_cis/db18c_V1.0.0.html) - paragraph 3.4
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_cis/db19c_V1.0.0.html) - paragraph 3.4
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Array] only
#    The list of object to only apply the control to.
#
# @param [Integer[20, 999]] preferred_value
#    The preferred value to use.
#    Some rules allow multiple values. The rule implement a default value, but when you want an other value, you can use this parameter.
#
#--++--
#
define ora_cis::controls::password_reuse_max_is_greater_than_or_equal_to_20(
  Array           $exclude         = ora_cis::lookup_setting('exclude', []),
  Array           $only            = ora_cis::lookup_setting('only', []),
  Integer[20,999] $preferred_value = ora_cis::lookup_setting('preferred_value', 20),
){
  $sid = $title
  ora_cis_setup { "password_reuse_max_is_greater_than_or_equal_to_20 on ${sid}":
    ensure => 'present'
  }
  -> ora_cis::internal::profile_setting{"password_reuse_max@${sid}":
    value   =>  $preferred_value,
    exclude => $exclude,
    only    => $only,
  }
}
