#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# ora_cis::init
#
# @summary defined type `ora_cis`
# Apply **all** Oracle database CIS rules to the specified database
# 
# Here is an example showing how to enable this rule:
# 
# ``` puppet
# ora_cis { 'DBNAME':
#   db_version  => 'db19c',
#   doc_version => 'V1.0.0',
# }
# ```
# 
# When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `db_version`. If you also don't specify a `db_version`, Puppet will detect the version of Oracle running and use this to determine the `db_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.
# 
# When you want to skip certain controls, you can use the `skip_list`.
# 
# ``` puppet
# ora_cis { 'DBNAME':
#   db_version  => 'db19c',
#   doc_version => 'V1.0.0',
#   skip_list   => [
#     'alter_database_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# ```
# 
# When you have multiple database on your system and want to use the same database version and CIS document version, you can do this:
# 
# ``` puppet
# Ora_cis {
#   db_version  => 'db19c',
#   doc_version => 'V1.0.0',
#   skip_list   => [
#     'alter_database_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# 
# ora_cis {'DB1':}
# ora_cis {'DB2':}
# ```
#
# @param title
#    The SID to apply the rule to.
#    All rules need an SID to apply the rule to. Here is a simple example:
#    ``` puppet
#    ora_cis::apply { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the rule to.
#
# @param db_version
#    The database version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) database version to your database.
#    If you also don't specify a `db_version`, Puppet will detect the version of Oracle running and use this to determine the `db_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_cis defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.
#
# @param doc_version
#    The version of the CIS benchmark you want to apply to your database.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `db_version`.
#
# @param all_controls
#    This is an internal parameter.
#    This is the Hash containing all paragraphs from the selected CIS benchmark.
#
# @param nonpdb_controls
#    This is an internal parameter.
#    It contains all of the controls that don't run on a pluggable database.
#
# @param skip_list
#    This is the list of controls that you want to skip.
#    By default this vale is empty, meaning `ora_cis` will apply **ALL** controls. You must specifiy the name of the control. Here is an example on how to do this:
#        ora_cis { 'MYDB':
#          db_version  => 'db19c',
#          doc_version => 'V1.0.0',
#          skip_list   => [
#            'alter_database_link_action_audit_is_enabled',
#            'alter_role_action_audit_is_enabled',
#          ]
#        }
#
#--++--
define ora_cis(
  Optional[String[1]] $db_version      = ora_cis::default_db_version($title),
  Optional[String[1]] $doc_version     = ora_cis::default_doc_version($db_version),
  Array               $skip_list       = [],
)
{
  if $db_version and $doc_version{
    ora_cis::validate_versions($db_version, $doc_version)
    $control_map     = lookup('ora_cis::control_map')
    $nonpdb_controls = lookup('ora_cis::nonpdb_controls')

    $sid = $title
    $sanitized_doc_version = regsubst($doc_version,/\./,'_','G').downcase

    echo {"Apply CIS controls ${db_version} ${doc_version} on ${sid}.": withpath => false,}

    if ora_config::is_pluggable_db($sid) {
        $current_controls = $control_map - $nonpdb_controls
        $nonpdb_controls.each | $paragraph, $control| {
          unless $control in $skip_list {
            alert("${control} in CIS skipped on ${title} because not applicable on pluggable database")
          }
        }
    } else {
      $current_controls = $control_map
    }

    $current_controls.each |String[1] $paragraph_name, String[1] $control_name | {
      $cis_name           = "${db_version}::${sanitized_doc_version}::${paragraph_name}::${sid.downcase}"
      $control_action_all = lookup("ora_cis::controls::${control_name}", String, undef, 'noskip' )
      $control_action_db  = lookup("ora_cis::controls::${control_name}::${sid.downcase}", String, undef, 'noskip' )

      if $control_action_all == 'skip' {
        debug("${control_name} for all databases skipped")
      } elsif $control_action_db == 'skip' or $control_name in $skip_list {
        debug("${control_name} for sid: ${sid} skipped")
      } else {
        # Generate puppet puppet_code
        $puppet_code = @("PUPPET")
        class $cis_name 
          {
            ora_cis::controls::$control_name { "${sid}": }
          }
        PUPPET
        easy_type::evaluate_puppet($puppet_code)
        include $cis_name
      }
    }
  } else {
    warning('skipping because db_version and/or doc_version is not set or found. Might be running on next run.')
  }
}
